import{_ as t,s as i,c as s,a as e,b as d,w as l,n as r,r as n,o as a}from"./index-CWKZ4Xq8.js";const p={components:{scrolly:i},data(){return{}}},c={style:{position:"relative",borderRadius:"8px",height:"100%"}},x={style:{position:"absolute",height:"100%",width:"100%",top:0,left:0,overflowY:"scroll",display:"flex"}},_=e("div",{style:{position:"relative",width:"20%",border:"2px solid white",borderRadius:"8px",boxSizing:"border-box",padding:"20px",display:"flex",flexDirection:"column"}},[e("div",null,[e("h1",null,"reel"),e("div",{style:{height:"20px"}}),e("div",{style:{padding:"0"}})])],-1),h=e("div",{style:{width:"20px"}},null,-1),b=e("div",{style:{position:"relative",boxSizing:"border-box",padding:"20px",width:"100%"}},null,-1);function u(y,v,g,f,w,m){const o=n("scrolly");return a(),s("div",c,[e("div",x,[_,h,d(o,{style:r({position:"relative",boxSizing:"border-box",padding:"20px",width:"100%",border:"2px solid white",background:"linear-gradient(22deg, #4d1eb540, #282020)",borderRadius:"8px"})},{default:l(()=>[b]),_:1},8,["style"])])])}const S=t(p,[["render",u]]);export{S as default};
