


def present ():
	return """

<!DOCTYPE html>	
<html>
<body
	style="
		padding: 20px;
		background: #222;
		color: #DDD;
		
		font-size: 3em;
	"
>
	<a href="/seed_generator">seed_generator</a>

</body>
</html>

		"""