import{i as u,G as c}from"./scenery-ca33b532.js";import{_ as b,d as m,n as h,r as l,o as g,c as _,a as e,b as d,w as a,j as i,v as s,i as v}from"./index-a898c826.js";import{s as y}from"./futon-32fc3a76.js";const w={inject:["vibes_store"],components:{scrolly:y,dashboard:m,instruments:u,Generate_Card:c,navigator:h},data(){return{flavor:"",story:"",performance:"",feeling:""}},methods:{async feel(){const r=await this.vibes_store.moves.feel({flavor:this.flavor,story:this.story,performance:this.performance});r.status=="pass"?this.feeling=r.note.feeling:console.error(r)}},mounted(){}},V={style:{position:"relative",borderRadius:"8px",color:"white",height:"100%"}},k={style:{position:"absolute",height:"100%",width:"100%",top:0,left:0,overflowY:"scroll",display:"flex"}},z=e("div",{style:{position:"relative",width:"20%",border:"2px solid white",borderRadius:"8px",boxSizing:"border-box",padding:"20px",display:"flex",flexDirection:"column"}},[e("div",null,[e("h1",null,"feel")])],-1),R=e("h2",null,"flavor",-1),S=e("h2",null,"story",-1),B=e("h2",null,"performance",-1),C=e("h2",null,"feeling",-1);function H(r,o,U,N,t,p){const x=l("VaButton"),f=l("scrolly");return g(),_("div",V,[e("div",k,[z,d(f,{style:{position:"relative",boxSizing:"border-box",padding:"20px",width:"100%"}},{default:a(()=>[R,i(e("textarea",{"onUpdate:modelValue":o[0]||(o[0]=n=>t.flavor=n),style:{width:"100%",minHeight:"100px",background:"none",borderRadius:"8px",boxSizing:"border-box",padding:"12px"}},null,512),[[s,t.flavor]]),S,i(e("textarea",{"onUpdate:modelValue":o[1]||(o[1]=n=>t.story=n),style:{width:"100%",minHeight:"200px",background:"none",borderRadius:"8px",boxSizing:"border-box",padding:"12px"}},null,512),[[s,t.story]]),B,i(e("textarea",{"onUpdate:modelValue":o[2]||(o[2]=n=>t.performance=n),style:{width:"100%",minHeight:"200px",background:"none",borderRadius:"8px",boxSizing:"border-box",padding:"12px"}},null,512),[[s,t.performance]]),d(x,{style:{margin:"5px 0 20px"},onClick:p.feel},{default:a(()=>[v("feel")]),_:1},8,["onClick"]),C,i(e("textarea",{"onUpdate:modelValue":o[3]||(o[3]=n=>t.feeling=n),style:{width:"100%",minHeight:"200px",background:"none",borderRadius:"8px",boxSizing:"border-box",padding:"12px"}},null,512),[[s,t.feeling]])]),_:1})])])}const T=b(w,[["render",H]]);export{T as default};
