import{i as l,G as p}from"./scenery-ca33b532.js";import{_ as c,d as m,n as x,r as b,o as h,c as u,a as e,j as n,v as i,b as f,w as _,i as v}from"./index-a898c826.js";const y={inject:["vibes_store"],components:{dashboard:m,instruments:l,Generate_Card:p,navigator:x},data(){return{retrieving_vibes:!0,vibes_alert:!1,vibes:[],show:"vibe maker",show_vibe:{name:""},styles:{vibe_styles:{margin:"4px 0"}},story:"",performance:""}},methods:{async perfom(){const o=await this.vibes_store.moves.perform({story:this.story});o.status==="pass"&&(this.performance=o.note.performance),console.log({proceeds:o})}},mounted(){}},g={style:{display:"flex",borderRadius:"8px",height:"100%",color:"white"}},w=e("div",{style:{position:"relative",width:"20%",border:"2px solid white",borderRadius:"8px",boxSizing:"border-box",padding:"20px",display:"flex",flexDirection:"column"}},[e("div",null,[e("h1",null,"Perform")])],-1),k={style:{boxSizing:"border-box",padding:"20px",width:"100%"}},V=e("p",null,'With a "vibe" and a "story", the "perform" button formulates a "performance" of the story.',-1),B=e("div",{style:{height:"100px"}},null,-1),C=e("h2",null,"story",-1),z=e("h2",null,"performance",-1);function R(o,t,S,N,r,a){const d=b("VaButton");return h(),u("div",g,[w,e("div",k,[V,B,C,n(e("textarea",{"onUpdate:modelValue":t[0]||(t[0]=s=>r.story=s),label:"story",style:{width:"100%",minHeight:"200px",background:"none",borderRadius:"8px",boxSizing:"border-box",padding:"12px"}},null,512),[[i,r.story]]),f(d,{onClick:a.perfom,style:{margin:"5px 0 20px"}},{default:_(()=>[v("Perform")]),_:1},8,["onClick"]),z,n(e("textarea",{"onUpdate:modelValue":t[1]||(t[1]=s=>r.performance=s),label:"performance",style:{width:"100%",minHeight:"200px",background:"none",borderRadius:"8px",boxSizing:"border-box",padding:"12px"}},null,512),[[i,r.performance]])])])}const G=c(y,[["render",R]]);export{G as default};
